jenkins-bot has submitted this change and it was merged. ( 
https://gerrit.wikimedia.org/r/351652 )

Change subject: Revert "Remove redundant Dashiki config"
......................................................................


Revert "Remove redundant Dashiki config"

This reverts commit 2b2a7ce9ed12c74f56b3d8f3b837137be70de9e5.

Change-Id: I46672e511e530595141af0322627518aaa2a483d
---
M wmf-config/CommonSettings.php
1 file changed, 12 insertions(+), 1 deletion(-)

Approvals:
  Milimetric: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/wmf-config/CommonSettings.php b/wmf-config/CommonSettings.php
index 53bf016..54132e6 100644
--- a/wmf-config/CommonSettings.php
+++ b/wmf-config/CommonSettings.php
@@ -3231,7 +3231,18 @@
 
 // Enable Config:Dashiki: sub-namespace on meta.wikimedia.org - T156971
 if ( $wmgEnableDashikiData ) {
-       // Dashiki sub-namespace Config:Dashiki: is configured in extension.json
+       // Configure Dashiki sub-namespace with JsonConfig
+       $wgJsonConfigs['JsonConfig.Dashiki'] = array(
+               'pattern' => '/^Dashiki\:./',
+               'isLocal' => true,
+       );
+
+       // register the custom view implemented by the Dashiki extension
+       $wgJsonConfigModels['JsonConfig.Dashiki'] = array(
+               'class' => null,
+               'view'  => 'Dashiki\DashikiView',
+       );
+
        wfLoadExtension( 'Dashiki' );
 }
 

-- 
To view, visit https://gerrit.wikimedia.org/r/351652
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I46672e511e530595141af0322627518aaa2a483d
Gerrit-PatchSet: 1
Gerrit-Project: operations/mediawiki-config
Gerrit-Branch: master
Gerrit-Owner: Milimetric <[email protected]>
Gerrit-Reviewer: Milimetric <[email protected]>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to